# This file was automatically generated by SWIG (https://www.swig.org).
# Version 4.3.1
#
# Do not make changes to this file unless you know what you are doing - modify
# the SWIG interface file instead.


import collections

from sys import version_info as _version_info
if _version_info < (3, 7, 0):
    raise RuntimeError("Python 3.7 or later required")

from . import _ITKCommonPython


from . import _ITKMetricsv4Python



from sys import version_info as _swig_python_version_info
# Import the low-level C/C++ module
if __package__ or "." in __name__:
    from . import _itkPointSetToPointSetMetricv4Python
else:
    import _itkPointSetToPointSetMetricv4Python

try:
    import builtins as __builtin__
except ImportError:
    import __builtin__

def _swig_repr(self):
    try:
        strthis = "proxy of " + self.this.__repr__()
    except __builtin__.Exception:
        strthis = ""
    return "<%s.%s; %s >" % (self.__class__.__module__, self.__class__.__name__, strthis,)


def _swig_setattr_nondynamic_instance_variable(set):
    def set_instance_attr(self, name, value):
        if name == "this":
            set(self, name, value)
        elif name == "thisown":
            self.this.own(value)
        elif hasattr(self, name) and isinstance(getattr(type(self), name), property):
            set(self, name, value)
        else:
            raise AttributeError("You cannot add instance attributes to %s" % self)
    return set_instance_attr


def _swig_setattr_nondynamic_class_variable(set):
    def set_class_attr(cls, name, value):
        if hasattr(cls, name) and not isinstance(getattr(cls, name), property):
            set(cls, name, value)
        else:
            raise AttributeError("You cannot add class attributes to %s" % cls)
    return set_class_attr


def _swig_add_metaclass(metaclass):
    """Class decorator for adding a metaclass to a SWIG wrapped class - a slimmed down version of six.add_metaclass"""
    def wrapper(cls):
        return metaclass(cls.__name__, cls.__bases__, cls.__dict__.copy())
    return wrapper


class _SwigNonDynamicMeta(type):
    """Meta class to enforce nondynamic attributes (no new attributes) for a class"""
    __setattr__ = _swig_setattr_nondynamic_class_variable(type.__setattr__)


if _swig_python_version_info[0:2] >= (3, 3):
    import collections.abc
else:
    import collections

import itk.itkObjectToObjectMetricBasePython
import itk.itkSingleValuedCostFunctionv4Python
import itk.itkCostFunctionPython
import itk.ITKCommonBasePython
import itk.itkMatrixPython
import itk.itkPointPython
import itk.itkFixedArrayPython
import itk.pyBasePython
import itk.vnl_vector_refPython
import itk.stdcomplexPython
import itk.vnl_vectorPython
import itk.vnl_matrixPython
import itk.itkVectorPython
import itk.itkCovariantVectorPython
import itk.vnl_matrix_fixedPython
import itk.itkArrayPython
import itk.itkOptimizerParametersPython
import itk.itkIndexPython
import itk.itkSizePython
import itk.itkOffsetPython
import itk.itkDisplacementFieldTransformPython
import itk.itkTransformBasePython
import itk.itkArray2DPython
import itk.itkSymmetricSecondRankTensorPython
import itk.itkVariableLengthVectorPython
import itk.itkDiffusionTensor3DPython
import itk.itkImagePython
import itk.itkImageRegionPython
import itk.itkRGBAPixelPython
import itk.itkRGBPixelPython
import itk.itkVectorImagePython
import itk.itkPointSetPython
import itk.itkVectorContainerPython
import itk.itkContinuousIndexPython
class itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass(itk.itkObjectToObjectMetricBasePython.itkObjectToObjectMetricBaseTemplateD):
    r"""Proxy of C++ itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetFixedTransform(self, _arg):
        r"""
        SetFixedTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD22 *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass_SetFixedTransform(self, _arg)

    def GetModifiableFixedTransform(self):
        r"""GetModifiableFixedTransform(self) -> itkTransformD22"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass_GetModifiableFixedTransform(self)

    def GetFixedTransform(self, *args):
        r"""
        GetFixedTransform(self) -> itkTransformD22
        GetFixedTransform(self) -> itkTransformD22
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass_GetFixedTransform(self, *args)

    def SetMovingTransform(self, _arg):
        r"""
        SetMovingTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD22 *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass_SetMovingTransform(self, _arg)

    def GetModifiableMovingTransform(self):
        r"""GetModifiableMovingTransform(self) -> itkTransformD22"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass_GetModifiableMovingTransform(self)

    def GetMovingTransform(self, *args):
        r"""
        GetMovingTransform(self) -> itkTransformD22
        GetMovingTransform(self) -> itkTransformD22
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass_GetMovingTransform(self, *args)

    def SetTransform(self, transform):
        r"""
        SetTransform(self, transform)

        Parameters
        ----------
        transform: itkTransformD22 *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass_SetTransform(self, transform)

    def GetTransform(self):
        r"""GetTransform(self) -> itkTransformD22"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass_GetTransform(self)

    def GetNumberOfValidPoints(self):
        r"""GetNumberOfValidPoints(self) -> unsigned long"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass_GetNumberOfValidPoints(self)

    def SetVirtualDomain(self, spacing, origin, direction, region):
        r"""
        SetVirtualDomain(self, spacing, origin, direction, region)

        Parameters
        ----------
        spacing: itkVectorD2 const &
        origin: itkPointD2 const &
        direction: itkMatrixD22 const &
        region: itkImageRegion2 const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass_SetVirtualDomain(self, spacing, origin, direction, region)

    def SetVirtualDomainFromImage(self, virtualImage):
        r"""
        SetVirtualDomainFromImage(self, virtualImage)

        Parameters
        ----------
        virtualImage: itkImageD2 const *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass_SetVirtualDomainFromImage(self, virtualImage)

    def SupportsArbitraryVirtualDomainSamples(self):
        r"""SupportsArbitraryVirtualDomainSamples(self) -> bool"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass_SupportsArbitraryVirtualDomainSamples(self)

    def GetVirtualDomainTimeStamp(self):
        r"""GetVirtualDomainTimeStamp(self) -> itkTimeStamp"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass_GetVirtualDomainTimeStamp(self)

    def GetVirtualSpacing(self):
        r"""GetVirtualSpacing(self) -> itkVectorD2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass_GetVirtualSpacing(self)

    def GetVirtualOrigin(self):
        r"""GetVirtualOrigin(self) -> itkPointD2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass_GetVirtualOrigin(self)

    def GetVirtualDirection(self):
        r"""GetVirtualDirection(self) -> itkMatrixD22"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass_GetVirtualDirection(self)

    def GetVirtualRegion(self):
        r"""GetVirtualRegion(self) -> itkImageRegion2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass_GetVirtualRegion(self)

    def GetModifiableVirtualImage(self):
        r"""GetModifiableVirtualImage(self) -> itkImageD2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass_GetModifiableVirtualImage(self)

    def GetVirtualImage(self, *args):
        r"""
        GetVirtualImage(self) -> itkImageD2
        GetVirtualImage(self) -> itkImageD2
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass_GetVirtualImage(self, *args)

    def ComputeParameterOffsetFromVirtualIndex(self, index, numberOfLocalParameters):
        r"""
        ComputeParameterOffsetFromVirtualIndex(self, index, numberOfLocalParameters) -> long

        Parameters
        ----------
        index: itkIndex2 const &
        numberOfLocalParameters: unsigned int const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass_ComputeParameterOffsetFromVirtualIndex(self, index, numberOfLocalParameters)

    def ComputeParameterOffsetFromVirtualPoint(self, point, numberOfLocalParameters):
        r"""
        ComputeParameterOffsetFromVirtualPoint(self, point, numberOfLocalParameters) -> long

        Parameters
        ----------
        point: itkPointD2 const &
        numberOfLocalParameters: unsigned int const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass_ComputeParameterOffsetFromVirtualPoint(self, point, numberOfLocalParameters)

    def IsInsideVirtualDomain(self, *args):
        r"""
        IsInsideVirtualDomain(self, point) -> bool

        Parameters
        ----------
        point: itkPointD2 const &

        IsInsideVirtualDomain(self, index) -> bool

        Parameters
        ----------
        index: itkIndex2 const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass_IsInsideVirtualDomain(self, *args)
    __swig_destroy__ = _itkPointSetToPointSetMetricv4Python.delete_itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass_cast(obj)

# Register itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass in _itkPointSetToPointSetMetricv4Python:
_itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass_swigregister(itkPointSetToPointSetMetricv4PSD2_Superclass_Superclass)
class itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass(itk.itkObjectToObjectMetricBasePython.itkObjectToObjectMetricBaseTemplateD):
    r"""Proxy of C++ itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetFixedTransform(self, _arg):
        r"""
        SetFixedTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD33 *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass_SetFixedTransform(self, _arg)

    def GetModifiableFixedTransform(self):
        r"""GetModifiableFixedTransform(self) -> itkTransformD33"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass_GetModifiableFixedTransform(self)

    def GetFixedTransform(self, *args):
        r"""
        GetFixedTransform(self) -> itkTransformD33
        GetFixedTransform(self) -> itkTransformD33
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass_GetFixedTransform(self, *args)

    def SetMovingTransform(self, _arg):
        r"""
        SetMovingTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD33 *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass_SetMovingTransform(self, _arg)

    def GetModifiableMovingTransform(self):
        r"""GetModifiableMovingTransform(self) -> itkTransformD33"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass_GetModifiableMovingTransform(self)

    def GetMovingTransform(self, *args):
        r"""
        GetMovingTransform(self) -> itkTransformD33
        GetMovingTransform(self) -> itkTransformD33
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass_GetMovingTransform(self, *args)

    def SetTransform(self, transform):
        r"""
        SetTransform(self, transform)

        Parameters
        ----------
        transform: itkTransformD33 *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass_SetTransform(self, transform)

    def GetTransform(self):
        r"""GetTransform(self) -> itkTransformD33"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass_GetTransform(self)

    def GetNumberOfValidPoints(self):
        r"""GetNumberOfValidPoints(self) -> unsigned long"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass_GetNumberOfValidPoints(self)

    def SetVirtualDomain(self, spacing, origin, direction, region):
        r"""
        SetVirtualDomain(self, spacing, origin, direction, region)

        Parameters
        ----------
        spacing: itkVectorD3 const &
        origin: itkPointD3 const &
        direction: itkMatrixD33 const &
        region: itkImageRegion3 const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass_SetVirtualDomain(self, spacing, origin, direction, region)

    def SetVirtualDomainFromImage(self, virtualImage):
        r"""
        SetVirtualDomainFromImage(self, virtualImage)

        Parameters
        ----------
        virtualImage: itkImageD3 const *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass_SetVirtualDomainFromImage(self, virtualImage)

    def SupportsArbitraryVirtualDomainSamples(self):
        r"""SupportsArbitraryVirtualDomainSamples(self) -> bool"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass_SupportsArbitraryVirtualDomainSamples(self)

    def GetVirtualDomainTimeStamp(self):
        r"""GetVirtualDomainTimeStamp(self) -> itkTimeStamp"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass_GetVirtualDomainTimeStamp(self)

    def GetVirtualSpacing(self):
        r"""GetVirtualSpacing(self) -> itkVectorD3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass_GetVirtualSpacing(self)

    def GetVirtualOrigin(self):
        r"""GetVirtualOrigin(self) -> itkPointD3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass_GetVirtualOrigin(self)

    def GetVirtualDirection(self):
        r"""GetVirtualDirection(self) -> itkMatrixD33"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass_GetVirtualDirection(self)

    def GetVirtualRegion(self):
        r"""GetVirtualRegion(self) -> itkImageRegion3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass_GetVirtualRegion(self)

    def GetModifiableVirtualImage(self):
        r"""GetModifiableVirtualImage(self) -> itkImageD3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass_GetModifiableVirtualImage(self)

    def GetVirtualImage(self, *args):
        r"""
        GetVirtualImage(self) -> itkImageD3
        GetVirtualImage(self) -> itkImageD3
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass_GetVirtualImage(self, *args)

    def ComputeParameterOffsetFromVirtualIndex(self, index, numberOfLocalParameters):
        r"""
        ComputeParameterOffsetFromVirtualIndex(self, index, numberOfLocalParameters) -> long

        Parameters
        ----------
        index: itkIndex3 const &
        numberOfLocalParameters: unsigned int const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass_ComputeParameterOffsetFromVirtualIndex(self, index, numberOfLocalParameters)

    def ComputeParameterOffsetFromVirtualPoint(self, point, numberOfLocalParameters):
        r"""
        ComputeParameterOffsetFromVirtualPoint(self, point, numberOfLocalParameters) -> long

        Parameters
        ----------
        point: itkPointD3 const &
        numberOfLocalParameters: unsigned int const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass_ComputeParameterOffsetFromVirtualPoint(self, point, numberOfLocalParameters)

    def IsInsideVirtualDomain(self, *args):
        r"""
        IsInsideVirtualDomain(self, point) -> bool

        Parameters
        ----------
        point: itkPointD3 const &

        IsInsideVirtualDomain(self, index) -> bool

        Parameters
        ----------
        index: itkIndex3 const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass_IsInsideVirtualDomain(self, *args)
    __swig_destroy__ = _itkPointSetToPointSetMetricv4Python.delete_itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass_cast(obj)

# Register itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass in _itkPointSetToPointSetMetricv4Python:
_itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass_swigregister(itkPointSetToPointSetMetricv4PSD3_Superclass_Superclass)
class itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass(itk.itkObjectToObjectMetricBasePython.itkObjectToObjectMetricBaseTemplateD):
    r"""Proxy of C++ itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetFixedTransform(self, _arg):
        r"""
        SetFixedTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD22 *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass_SetFixedTransform(self, _arg)

    def GetModifiableFixedTransform(self):
        r"""GetModifiableFixedTransform(self) -> itkTransformD22"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass_GetModifiableFixedTransform(self)

    def GetFixedTransform(self, *args):
        r"""
        GetFixedTransform(self) -> itkTransformD22
        GetFixedTransform(self) -> itkTransformD22
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass_GetFixedTransform(self, *args)

    def SetMovingTransform(self, _arg):
        r"""
        SetMovingTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD22 *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass_SetMovingTransform(self, _arg)

    def GetModifiableMovingTransform(self):
        r"""GetModifiableMovingTransform(self) -> itkTransformD22"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass_GetModifiableMovingTransform(self)

    def GetMovingTransform(self, *args):
        r"""
        GetMovingTransform(self) -> itkTransformD22
        GetMovingTransform(self) -> itkTransformD22
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass_GetMovingTransform(self, *args)

    def SetTransform(self, transform):
        r"""
        SetTransform(self, transform)

        Parameters
        ----------
        transform: itkTransformD22 *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass_SetTransform(self, transform)

    def GetTransform(self):
        r"""GetTransform(self) -> itkTransformD22"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass_GetTransform(self)

    def GetNumberOfValidPoints(self):
        r"""GetNumberOfValidPoints(self) -> unsigned long"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass_GetNumberOfValidPoints(self)

    def SetVirtualDomain(self, spacing, origin, direction, region):
        r"""
        SetVirtualDomain(self, spacing, origin, direction, region)

        Parameters
        ----------
        spacing: itkVectorD2 const &
        origin: itkPointD2 const &
        direction: itkMatrixD22 const &
        region: itkImageRegion2 const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass_SetVirtualDomain(self, spacing, origin, direction, region)

    def SetVirtualDomainFromImage(self, virtualImage):
        r"""
        SetVirtualDomainFromImage(self, virtualImage)

        Parameters
        ----------
        virtualImage: itkImageD2 const *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass_SetVirtualDomainFromImage(self, virtualImage)

    def SupportsArbitraryVirtualDomainSamples(self):
        r"""SupportsArbitraryVirtualDomainSamples(self) -> bool"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass_SupportsArbitraryVirtualDomainSamples(self)

    def GetVirtualDomainTimeStamp(self):
        r"""GetVirtualDomainTimeStamp(self) -> itkTimeStamp"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass_GetVirtualDomainTimeStamp(self)

    def GetVirtualSpacing(self):
        r"""GetVirtualSpacing(self) -> itkVectorD2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass_GetVirtualSpacing(self)

    def GetVirtualOrigin(self):
        r"""GetVirtualOrigin(self) -> itkPointD2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass_GetVirtualOrigin(self)

    def GetVirtualDirection(self):
        r"""GetVirtualDirection(self) -> itkMatrixD22"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass_GetVirtualDirection(self)

    def GetVirtualRegion(self):
        r"""GetVirtualRegion(self) -> itkImageRegion2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass_GetVirtualRegion(self)

    def GetModifiableVirtualImage(self):
        r"""GetModifiableVirtualImage(self) -> itkImageD2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass_GetModifiableVirtualImage(self)

    def GetVirtualImage(self, *args):
        r"""
        GetVirtualImage(self) -> itkImageD2
        GetVirtualImage(self) -> itkImageD2
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass_GetVirtualImage(self, *args)

    def ComputeParameterOffsetFromVirtualIndex(self, index, numberOfLocalParameters):
        r"""
        ComputeParameterOffsetFromVirtualIndex(self, index, numberOfLocalParameters) -> long

        Parameters
        ----------
        index: itkIndex2 const &
        numberOfLocalParameters: unsigned int const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass_ComputeParameterOffsetFromVirtualIndex(self, index, numberOfLocalParameters)

    def ComputeParameterOffsetFromVirtualPoint(self, point, numberOfLocalParameters):
        r"""
        ComputeParameterOffsetFromVirtualPoint(self, point, numberOfLocalParameters) -> long

        Parameters
        ----------
        point: itkPointD2 const &
        numberOfLocalParameters: unsigned int const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass_ComputeParameterOffsetFromVirtualPoint(self, point, numberOfLocalParameters)

    def IsInsideVirtualDomain(self, *args):
        r"""
        IsInsideVirtualDomain(self, point) -> bool

        Parameters
        ----------
        point: itkPointD2 const &

        IsInsideVirtualDomain(self, index) -> bool

        Parameters
        ----------
        index: itkIndex2 const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass_IsInsideVirtualDomain(self, *args)
    __swig_destroy__ = _itkPointSetToPointSetMetricv4Python.delete_itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass_cast(obj)

# Register itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass in _itkPointSetToPointSetMetricv4Python:
_itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass_swigregister(itkPointSetToPointSetMetricv4PSF2_Superclass_Superclass)
class itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass(itk.itkObjectToObjectMetricBasePython.itkObjectToObjectMetricBaseTemplateD):
    r"""Proxy of C++ itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetFixedTransform(self, _arg):
        r"""
        SetFixedTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD33 *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass_SetFixedTransform(self, _arg)

    def GetModifiableFixedTransform(self):
        r"""GetModifiableFixedTransform(self) -> itkTransformD33"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass_GetModifiableFixedTransform(self)

    def GetFixedTransform(self, *args):
        r"""
        GetFixedTransform(self) -> itkTransformD33
        GetFixedTransform(self) -> itkTransformD33
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass_GetFixedTransform(self, *args)

    def SetMovingTransform(self, _arg):
        r"""
        SetMovingTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD33 *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass_SetMovingTransform(self, _arg)

    def GetModifiableMovingTransform(self):
        r"""GetModifiableMovingTransform(self) -> itkTransformD33"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass_GetModifiableMovingTransform(self)

    def GetMovingTransform(self, *args):
        r"""
        GetMovingTransform(self) -> itkTransformD33
        GetMovingTransform(self) -> itkTransformD33
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass_GetMovingTransform(self, *args)

    def SetTransform(self, transform):
        r"""
        SetTransform(self, transform)

        Parameters
        ----------
        transform: itkTransformD33 *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass_SetTransform(self, transform)

    def GetTransform(self):
        r"""GetTransform(self) -> itkTransformD33"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass_GetTransform(self)

    def GetNumberOfValidPoints(self):
        r"""GetNumberOfValidPoints(self) -> unsigned long"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass_GetNumberOfValidPoints(self)

    def SetVirtualDomain(self, spacing, origin, direction, region):
        r"""
        SetVirtualDomain(self, spacing, origin, direction, region)

        Parameters
        ----------
        spacing: itkVectorD3 const &
        origin: itkPointD3 const &
        direction: itkMatrixD33 const &
        region: itkImageRegion3 const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass_SetVirtualDomain(self, spacing, origin, direction, region)

    def SetVirtualDomainFromImage(self, virtualImage):
        r"""
        SetVirtualDomainFromImage(self, virtualImage)

        Parameters
        ----------
        virtualImage: itkImageD3 const *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass_SetVirtualDomainFromImage(self, virtualImage)

    def SupportsArbitraryVirtualDomainSamples(self):
        r"""SupportsArbitraryVirtualDomainSamples(self) -> bool"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass_SupportsArbitraryVirtualDomainSamples(self)

    def GetVirtualDomainTimeStamp(self):
        r"""GetVirtualDomainTimeStamp(self) -> itkTimeStamp"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass_GetVirtualDomainTimeStamp(self)

    def GetVirtualSpacing(self):
        r"""GetVirtualSpacing(self) -> itkVectorD3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass_GetVirtualSpacing(self)

    def GetVirtualOrigin(self):
        r"""GetVirtualOrigin(self) -> itkPointD3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass_GetVirtualOrigin(self)

    def GetVirtualDirection(self):
        r"""GetVirtualDirection(self) -> itkMatrixD33"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass_GetVirtualDirection(self)

    def GetVirtualRegion(self):
        r"""GetVirtualRegion(self) -> itkImageRegion3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass_GetVirtualRegion(self)

    def GetModifiableVirtualImage(self):
        r"""GetModifiableVirtualImage(self) -> itkImageD3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass_GetModifiableVirtualImage(self)

    def GetVirtualImage(self, *args):
        r"""
        GetVirtualImage(self) -> itkImageD3
        GetVirtualImage(self) -> itkImageD3
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass_GetVirtualImage(self, *args)

    def ComputeParameterOffsetFromVirtualIndex(self, index, numberOfLocalParameters):
        r"""
        ComputeParameterOffsetFromVirtualIndex(self, index, numberOfLocalParameters) -> long

        Parameters
        ----------
        index: itkIndex3 const &
        numberOfLocalParameters: unsigned int const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass_ComputeParameterOffsetFromVirtualIndex(self, index, numberOfLocalParameters)

    def ComputeParameterOffsetFromVirtualPoint(self, point, numberOfLocalParameters):
        r"""
        ComputeParameterOffsetFromVirtualPoint(self, point, numberOfLocalParameters) -> long

        Parameters
        ----------
        point: itkPointD3 const &
        numberOfLocalParameters: unsigned int const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass_ComputeParameterOffsetFromVirtualPoint(self, point, numberOfLocalParameters)

    def IsInsideVirtualDomain(self, *args):
        r"""
        IsInsideVirtualDomain(self, point) -> bool

        Parameters
        ----------
        point: itkPointD3 const &

        IsInsideVirtualDomain(self, index) -> bool

        Parameters
        ----------
        index: itkIndex3 const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass_IsInsideVirtualDomain(self, *args)
    __swig_destroy__ = _itkPointSetToPointSetMetricv4Python.delete_itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass_cast(obj)

# Register itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass in _itkPointSetToPointSetMetricv4Python:
_itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass_swigregister(itkPointSetToPointSetMetricv4PSF3_Superclass_Superclass)
class itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass(itk.itkObjectToObjectMetricBasePython.itkObjectToObjectMetricBaseTemplateD):
    r"""Proxy of C++ itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetFixedTransform(self, _arg):
        r"""
        SetFixedTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD22 *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass_SetFixedTransform(self, _arg)

    def GetModifiableFixedTransform(self):
        r"""GetModifiableFixedTransform(self) -> itkTransformD22"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass_GetModifiableFixedTransform(self)

    def GetFixedTransform(self, *args):
        r"""
        GetFixedTransform(self) -> itkTransformD22
        GetFixedTransform(self) -> itkTransformD22
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass_GetFixedTransform(self, *args)

    def SetMovingTransform(self, _arg):
        r"""
        SetMovingTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD22 *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass_SetMovingTransform(self, _arg)

    def GetModifiableMovingTransform(self):
        r"""GetModifiableMovingTransform(self) -> itkTransformD22"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass_GetModifiableMovingTransform(self)

    def GetMovingTransform(self, *args):
        r"""
        GetMovingTransform(self) -> itkTransformD22
        GetMovingTransform(self) -> itkTransformD22
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass_GetMovingTransform(self, *args)

    def SetTransform(self, transform):
        r"""
        SetTransform(self, transform)

        Parameters
        ----------
        transform: itkTransformD22 *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass_SetTransform(self, transform)

    def GetTransform(self):
        r"""GetTransform(self) -> itkTransformD22"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass_GetTransform(self)

    def GetNumberOfValidPoints(self):
        r"""GetNumberOfValidPoints(self) -> unsigned long"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass_GetNumberOfValidPoints(self)

    def SetVirtualDomain(self, spacing, origin, direction, region):
        r"""
        SetVirtualDomain(self, spacing, origin, direction, region)

        Parameters
        ----------
        spacing: itkVectorD2 const &
        origin: itkPointD2 const &
        direction: itkMatrixD22 const &
        region: itkImageRegion2 const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass_SetVirtualDomain(self, spacing, origin, direction, region)

    def SetVirtualDomainFromImage(self, virtualImage):
        r"""
        SetVirtualDomainFromImage(self, virtualImage)

        Parameters
        ----------
        virtualImage: itkImageD2 const *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass_SetVirtualDomainFromImage(self, virtualImage)

    def SupportsArbitraryVirtualDomainSamples(self):
        r"""SupportsArbitraryVirtualDomainSamples(self) -> bool"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass_SupportsArbitraryVirtualDomainSamples(self)

    def GetVirtualDomainTimeStamp(self):
        r"""GetVirtualDomainTimeStamp(self) -> itkTimeStamp"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass_GetVirtualDomainTimeStamp(self)

    def GetVirtualSpacing(self):
        r"""GetVirtualSpacing(self) -> itkVectorD2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass_GetVirtualSpacing(self)

    def GetVirtualOrigin(self):
        r"""GetVirtualOrigin(self) -> itkPointD2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass_GetVirtualOrigin(self)

    def GetVirtualDirection(self):
        r"""GetVirtualDirection(self) -> itkMatrixD22"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass_GetVirtualDirection(self)

    def GetVirtualRegion(self):
        r"""GetVirtualRegion(self) -> itkImageRegion2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass_GetVirtualRegion(self)

    def GetModifiableVirtualImage(self):
        r"""GetModifiableVirtualImage(self) -> itkImageD2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass_GetModifiableVirtualImage(self)

    def GetVirtualImage(self, *args):
        r"""
        GetVirtualImage(self) -> itkImageD2
        GetVirtualImage(self) -> itkImageD2
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass_GetVirtualImage(self, *args)

    def ComputeParameterOffsetFromVirtualIndex(self, index, numberOfLocalParameters):
        r"""
        ComputeParameterOffsetFromVirtualIndex(self, index, numberOfLocalParameters) -> long

        Parameters
        ----------
        index: itkIndex2 const &
        numberOfLocalParameters: unsigned int const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass_ComputeParameterOffsetFromVirtualIndex(self, index, numberOfLocalParameters)

    def ComputeParameterOffsetFromVirtualPoint(self, point, numberOfLocalParameters):
        r"""
        ComputeParameterOffsetFromVirtualPoint(self, point, numberOfLocalParameters) -> long

        Parameters
        ----------
        point: itkPointD2 const &
        numberOfLocalParameters: unsigned int const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass_ComputeParameterOffsetFromVirtualPoint(self, point, numberOfLocalParameters)

    def IsInsideVirtualDomain(self, *args):
        r"""
        IsInsideVirtualDomain(self, point) -> bool

        Parameters
        ----------
        point: itkPointD2 const &

        IsInsideVirtualDomain(self, index) -> bool

        Parameters
        ----------
        index: itkIndex2 const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass_IsInsideVirtualDomain(self, *args)
    __swig_destroy__ = _itkPointSetToPointSetMetricv4Python.delete_itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass_cast(obj)

# Register itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass in _itkPointSetToPointSetMetricv4Python:
_itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass_swigregister(itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass)
class itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass(itk.itkObjectToObjectMetricBasePython.itkObjectToObjectMetricBaseTemplateD):
    r"""Proxy of C++ itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetFixedTransform(self, _arg):
        r"""
        SetFixedTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD33 *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass_SetFixedTransform(self, _arg)

    def GetModifiableFixedTransform(self):
        r"""GetModifiableFixedTransform(self) -> itkTransformD33"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass_GetModifiableFixedTransform(self)

    def GetFixedTransform(self, *args):
        r"""
        GetFixedTransform(self) -> itkTransformD33
        GetFixedTransform(self) -> itkTransformD33
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass_GetFixedTransform(self, *args)

    def SetMovingTransform(self, _arg):
        r"""
        SetMovingTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD33 *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass_SetMovingTransform(self, _arg)

    def GetModifiableMovingTransform(self):
        r"""GetModifiableMovingTransform(self) -> itkTransformD33"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass_GetModifiableMovingTransform(self)

    def GetMovingTransform(self, *args):
        r"""
        GetMovingTransform(self) -> itkTransformD33
        GetMovingTransform(self) -> itkTransformD33
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass_GetMovingTransform(self, *args)

    def SetTransform(self, transform):
        r"""
        SetTransform(self, transform)

        Parameters
        ----------
        transform: itkTransformD33 *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass_SetTransform(self, transform)

    def GetTransform(self):
        r"""GetTransform(self) -> itkTransformD33"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass_GetTransform(self)

    def GetNumberOfValidPoints(self):
        r"""GetNumberOfValidPoints(self) -> unsigned long"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass_GetNumberOfValidPoints(self)

    def SetVirtualDomain(self, spacing, origin, direction, region):
        r"""
        SetVirtualDomain(self, spacing, origin, direction, region)

        Parameters
        ----------
        spacing: itkVectorD3 const &
        origin: itkPointD3 const &
        direction: itkMatrixD33 const &
        region: itkImageRegion3 const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass_SetVirtualDomain(self, spacing, origin, direction, region)

    def SetVirtualDomainFromImage(self, virtualImage):
        r"""
        SetVirtualDomainFromImage(self, virtualImage)

        Parameters
        ----------
        virtualImage: itkImageD3 const *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass_SetVirtualDomainFromImage(self, virtualImage)

    def SupportsArbitraryVirtualDomainSamples(self):
        r"""SupportsArbitraryVirtualDomainSamples(self) -> bool"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass_SupportsArbitraryVirtualDomainSamples(self)

    def GetVirtualDomainTimeStamp(self):
        r"""GetVirtualDomainTimeStamp(self) -> itkTimeStamp"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass_GetVirtualDomainTimeStamp(self)

    def GetVirtualSpacing(self):
        r"""GetVirtualSpacing(self) -> itkVectorD3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass_GetVirtualSpacing(self)

    def GetVirtualOrigin(self):
        r"""GetVirtualOrigin(self) -> itkPointD3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass_GetVirtualOrigin(self)

    def GetVirtualDirection(self):
        r"""GetVirtualDirection(self) -> itkMatrixD33"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass_GetVirtualDirection(self)

    def GetVirtualRegion(self):
        r"""GetVirtualRegion(self) -> itkImageRegion3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass_GetVirtualRegion(self)

    def GetModifiableVirtualImage(self):
        r"""GetModifiableVirtualImage(self) -> itkImageD3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass_GetModifiableVirtualImage(self)

    def GetVirtualImage(self, *args):
        r"""
        GetVirtualImage(self) -> itkImageD3
        GetVirtualImage(self) -> itkImageD3
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass_GetVirtualImage(self, *args)

    def ComputeParameterOffsetFromVirtualIndex(self, index, numberOfLocalParameters):
        r"""
        ComputeParameterOffsetFromVirtualIndex(self, index, numberOfLocalParameters) -> long

        Parameters
        ----------
        index: itkIndex3 const &
        numberOfLocalParameters: unsigned int const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass_ComputeParameterOffsetFromVirtualIndex(self, index, numberOfLocalParameters)

    def ComputeParameterOffsetFromVirtualPoint(self, point, numberOfLocalParameters):
        r"""
        ComputeParameterOffsetFromVirtualPoint(self, point, numberOfLocalParameters) -> long

        Parameters
        ----------
        point: itkPointD3 const &
        numberOfLocalParameters: unsigned int const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass_ComputeParameterOffsetFromVirtualPoint(self, point, numberOfLocalParameters)

    def IsInsideVirtualDomain(self, *args):
        r"""
        IsInsideVirtualDomain(self, point) -> bool

        Parameters
        ----------
        point: itkPointD3 const &

        IsInsideVirtualDomain(self, index) -> bool

        Parameters
        ----------
        index: itkIndex3 const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass_IsInsideVirtualDomain(self, *args)
    __swig_destroy__ = _itkPointSetToPointSetMetricv4Python.delete_itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass_cast(obj)

# Register itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass in _itkPointSetToPointSetMetricv4Python:
_itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass_swigregister(itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass)
class itkPointSetToPointSetMetricv4PSUC2_Superclass(itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass):
    r"""Proxy of C++ itkPointSetToPointSetMetricv4PSUC2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetFixedPointSet(self, _arg):
        r"""
        SetFixedPointSet(self, _arg)

        Parameters
        ----------
        _arg: itkPointSetUC2 const *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_SetFixedPointSet(self, _arg)

    def GetFixedPointSet(self):
        r"""GetFixedPointSet(self) -> itkPointSetUC2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_GetFixedPointSet(self)

    def GetModifiableFixedTransformedPointSet(self):
        r"""GetModifiableFixedTransformedPointSet(self) -> itkPointSetUC2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_GetModifiableFixedTransformedPointSet(self)

    def GetFixedTransformedPointSet(self, *args):
        r"""
        GetFixedTransformedPointSet(self) -> itkPointSetUC2
        GetFixedTransformedPointSet(self) -> itkPointSetUC2
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_GetFixedTransformedPointSet(self, *args)

    def SetMovingPointSet(self, _arg):
        r"""
        SetMovingPointSet(self, _arg)

        Parameters
        ----------
        _arg: itkPointSetUC2 const *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_SetMovingPointSet(self, _arg)

    def GetMovingPointSet(self):
        r"""GetMovingPointSet(self) -> itkPointSetUC2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_GetMovingPointSet(self)

    def GetModifiableMovingTransformedPointSet(self):
        r"""GetModifiableMovingTransformedPointSet(self) -> itkPointSetUC2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_GetModifiableMovingTransformedPointSet(self)

    def GetMovingTransformedPointSet(self, *args):
        r"""
        GetMovingTransformedPointSet(self) -> itkPointSetUC2
        GetMovingTransformedPointSet(self) -> itkPointSetUC2
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_GetMovingTransformedPointSet(self, *args)

    def GetNumberOfComponents(self):
        r"""GetNumberOfComponents(self) -> unsigned long"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_GetNumberOfComponents(self)

    def GetVirtualTransformedPointSet(self):
        r"""GetVirtualTransformedPointSet(self) -> itkPointSetD2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_GetVirtualTransformedPointSet(self)

    def SetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self, _arg):
        r"""
        SetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_SetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self, _arg)

    def GetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self):
        r"""GetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self) -> bool"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_GetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self)

    def StoreDerivativeAsSparseFieldForLocalSupportTransformsOn(self):
        r"""StoreDerivativeAsSparseFieldForLocalSupportTransformsOn(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_StoreDerivativeAsSparseFieldForLocalSupportTransformsOn(self)

    def StoreDerivativeAsSparseFieldForLocalSupportTransformsOff(self):
        r"""StoreDerivativeAsSparseFieldForLocalSupportTransformsOff(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_StoreDerivativeAsSparseFieldForLocalSupportTransformsOff(self)

    def SetCalculateValueAndDerivativeInTangentSpace(self, _arg):
        r"""
        SetCalculateValueAndDerivativeInTangentSpace(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_SetCalculateValueAndDerivativeInTangentSpace(self, _arg)

    def GetCalculateValueAndDerivativeInTangentSpace(self):
        r"""GetCalculateValueAndDerivativeInTangentSpace(self) -> bool"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_GetCalculateValueAndDerivativeInTangentSpace(self)

    def CalculateValueAndDerivativeInTangentSpaceOn(self):
        r"""CalculateValueAndDerivativeInTangentSpaceOn(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_CalculateValueAndDerivativeInTangentSpaceOn(self)

    def CalculateValueAndDerivativeInTangentSpaceOff(self):
        r"""CalculateValueAndDerivativeInTangentSpaceOff(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_CalculateValueAndDerivativeInTangentSpaceOff(self)
    __swig_destroy__ = _itkPointSetToPointSetMetricv4Python.delete_itkPointSetToPointSetMetricv4PSUC2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointSetToPointSetMetricv4PSUC2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_cast(obj)

# Register itkPointSetToPointSetMetricv4PSUC2_Superclass in _itkPointSetToPointSetMetricv4Python:
_itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_swigregister(itkPointSetToPointSetMetricv4PSUC2_Superclass)
class itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass(itk.itkObjectToObjectMetricBasePython.itkObjectToObjectMetricBaseTemplateD):
    r"""Proxy of C++ itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetFixedTransform(self, _arg):
        r"""
        SetFixedTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD22 *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass_SetFixedTransform(self, _arg)

    def GetModifiableFixedTransform(self):
        r"""GetModifiableFixedTransform(self) -> itkTransformD22"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass_GetModifiableFixedTransform(self)

    def GetFixedTransform(self, *args):
        r"""
        GetFixedTransform(self) -> itkTransformD22
        GetFixedTransform(self) -> itkTransformD22
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass_GetFixedTransform(self, *args)

    def SetMovingTransform(self, _arg):
        r"""
        SetMovingTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD22 *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass_SetMovingTransform(self, _arg)

    def GetModifiableMovingTransform(self):
        r"""GetModifiableMovingTransform(self) -> itkTransformD22"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass_GetModifiableMovingTransform(self)

    def GetMovingTransform(self, *args):
        r"""
        GetMovingTransform(self) -> itkTransformD22
        GetMovingTransform(self) -> itkTransformD22
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass_GetMovingTransform(self, *args)

    def SetTransform(self, transform):
        r"""
        SetTransform(self, transform)

        Parameters
        ----------
        transform: itkTransformD22 *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass_SetTransform(self, transform)

    def GetTransform(self):
        r"""GetTransform(self) -> itkTransformD22"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass_GetTransform(self)

    def GetNumberOfValidPoints(self):
        r"""GetNumberOfValidPoints(self) -> unsigned long"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass_GetNumberOfValidPoints(self)

    def SetVirtualDomain(self, spacing, origin, direction, region):
        r"""
        SetVirtualDomain(self, spacing, origin, direction, region)

        Parameters
        ----------
        spacing: itkVectorD2 const &
        origin: itkPointD2 const &
        direction: itkMatrixD22 const &
        region: itkImageRegion2 const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass_SetVirtualDomain(self, spacing, origin, direction, region)

    def SetVirtualDomainFromImage(self, virtualImage):
        r"""
        SetVirtualDomainFromImage(self, virtualImage)

        Parameters
        ----------
        virtualImage: itkImageD2 const *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass_SetVirtualDomainFromImage(self, virtualImage)

    def SupportsArbitraryVirtualDomainSamples(self):
        r"""SupportsArbitraryVirtualDomainSamples(self) -> bool"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass_SupportsArbitraryVirtualDomainSamples(self)

    def GetVirtualDomainTimeStamp(self):
        r"""GetVirtualDomainTimeStamp(self) -> itkTimeStamp"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass_GetVirtualDomainTimeStamp(self)

    def GetVirtualSpacing(self):
        r"""GetVirtualSpacing(self) -> itkVectorD2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass_GetVirtualSpacing(self)

    def GetVirtualOrigin(self):
        r"""GetVirtualOrigin(self) -> itkPointD2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass_GetVirtualOrigin(self)

    def GetVirtualDirection(self):
        r"""GetVirtualDirection(self) -> itkMatrixD22"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass_GetVirtualDirection(self)

    def GetVirtualRegion(self):
        r"""GetVirtualRegion(self) -> itkImageRegion2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass_GetVirtualRegion(self)

    def GetModifiableVirtualImage(self):
        r"""GetModifiableVirtualImage(self) -> itkImageD2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass_GetModifiableVirtualImage(self)

    def GetVirtualImage(self, *args):
        r"""
        GetVirtualImage(self) -> itkImageD2
        GetVirtualImage(self) -> itkImageD2
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass_GetVirtualImage(self, *args)

    def ComputeParameterOffsetFromVirtualIndex(self, index, numberOfLocalParameters):
        r"""
        ComputeParameterOffsetFromVirtualIndex(self, index, numberOfLocalParameters) -> long

        Parameters
        ----------
        index: itkIndex2 const &
        numberOfLocalParameters: unsigned int const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass_ComputeParameterOffsetFromVirtualIndex(self, index, numberOfLocalParameters)

    def ComputeParameterOffsetFromVirtualPoint(self, point, numberOfLocalParameters):
        r"""
        ComputeParameterOffsetFromVirtualPoint(self, point, numberOfLocalParameters) -> long

        Parameters
        ----------
        point: itkPointD2 const &
        numberOfLocalParameters: unsigned int const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass_ComputeParameterOffsetFromVirtualPoint(self, point, numberOfLocalParameters)

    def IsInsideVirtualDomain(self, *args):
        r"""
        IsInsideVirtualDomain(self, point) -> bool

        Parameters
        ----------
        point: itkPointD2 const &

        IsInsideVirtualDomain(self, index) -> bool

        Parameters
        ----------
        index: itkIndex2 const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass_IsInsideVirtualDomain(self, *args)
    __swig_destroy__ = _itkPointSetToPointSetMetricv4Python.delete_itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass_cast(obj)

# Register itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass in _itkPointSetToPointSetMetricv4Python:
_itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass_swigregister(itkPointSetToPointSetMetricv4PSUC2_Superclass_Superclass)
class itkPointSetToPointSetMetricv4PSUC3_Superclass(itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass):
    r"""Proxy of C++ itkPointSetToPointSetMetricv4PSUC3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetFixedPointSet(self, _arg):
        r"""
        SetFixedPointSet(self, _arg)

        Parameters
        ----------
        _arg: itkPointSetUC3 const *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_SetFixedPointSet(self, _arg)

    def GetFixedPointSet(self):
        r"""GetFixedPointSet(self) -> itkPointSetUC3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_GetFixedPointSet(self)

    def GetModifiableFixedTransformedPointSet(self):
        r"""GetModifiableFixedTransformedPointSet(self) -> itkPointSetUC3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_GetModifiableFixedTransformedPointSet(self)

    def GetFixedTransformedPointSet(self, *args):
        r"""
        GetFixedTransformedPointSet(self) -> itkPointSetUC3
        GetFixedTransformedPointSet(self) -> itkPointSetUC3
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_GetFixedTransformedPointSet(self, *args)

    def SetMovingPointSet(self, _arg):
        r"""
        SetMovingPointSet(self, _arg)

        Parameters
        ----------
        _arg: itkPointSetUC3 const *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_SetMovingPointSet(self, _arg)

    def GetMovingPointSet(self):
        r"""GetMovingPointSet(self) -> itkPointSetUC3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_GetMovingPointSet(self)

    def GetModifiableMovingTransformedPointSet(self):
        r"""GetModifiableMovingTransformedPointSet(self) -> itkPointSetUC3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_GetModifiableMovingTransformedPointSet(self)

    def GetMovingTransformedPointSet(self, *args):
        r"""
        GetMovingTransformedPointSet(self) -> itkPointSetUC3
        GetMovingTransformedPointSet(self) -> itkPointSetUC3
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_GetMovingTransformedPointSet(self, *args)

    def GetNumberOfComponents(self):
        r"""GetNumberOfComponents(self) -> unsigned long"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_GetNumberOfComponents(self)

    def GetVirtualTransformedPointSet(self):
        r"""GetVirtualTransformedPointSet(self) -> itkPointSetD3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_GetVirtualTransformedPointSet(self)

    def SetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self, _arg):
        r"""
        SetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_SetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self, _arg)

    def GetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self):
        r"""GetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self) -> bool"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_GetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self)

    def StoreDerivativeAsSparseFieldForLocalSupportTransformsOn(self):
        r"""StoreDerivativeAsSparseFieldForLocalSupportTransformsOn(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_StoreDerivativeAsSparseFieldForLocalSupportTransformsOn(self)

    def StoreDerivativeAsSparseFieldForLocalSupportTransformsOff(self):
        r"""StoreDerivativeAsSparseFieldForLocalSupportTransformsOff(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_StoreDerivativeAsSparseFieldForLocalSupportTransformsOff(self)

    def SetCalculateValueAndDerivativeInTangentSpace(self, _arg):
        r"""
        SetCalculateValueAndDerivativeInTangentSpace(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_SetCalculateValueAndDerivativeInTangentSpace(self, _arg)

    def GetCalculateValueAndDerivativeInTangentSpace(self):
        r"""GetCalculateValueAndDerivativeInTangentSpace(self) -> bool"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_GetCalculateValueAndDerivativeInTangentSpace(self)

    def CalculateValueAndDerivativeInTangentSpaceOn(self):
        r"""CalculateValueAndDerivativeInTangentSpaceOn(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_CalculateValueAndDerivativeInTangentSpaceOn(self)

    def CalculateValueAndDerivativeInTangentSpaceOff(self):
        r"""CalculateValueAndDerivativeInTangentSpaceOff(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_CalculateValueAndDerivativeInTangentSpaceOff(self)
    __swig_destroy__ = _itkPointSetToPointSetMetricv4Python.delete_itkPointSetToPointSetMetricv4PSUC3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointSetToPointSetMetricv4PSUC3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_cast(obj)

# Register itkPointSetToPointSetMetricv4PSUC3_Superclass in _itkPointSetToPointSetMetricv4Python:
_itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_swigregister(itkPointSetToPointSetMetricv4PSUC3_Superclass)
class itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass(itk.itkObjectToObjectMetricBasePython.itkObjectToObjectMetricBaseTemplateD):
    r"""Proxy of C++ itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetFixedTransform(self, _arg):
        r"""
        SetFixedTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD33 *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass_SetFixedTransform(self, _arg)

    def GetModifiableFixedTransform(self):
        r"""GetModifiableFixedTransform(self) -> itkTransformD33"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass_GetModifiableFixedTransform(self)

    def GetFixedTransform(self, *args):
        r"""
        GetFixedTransform(self) -> itkTransformD33
        GetFixedTransform(self) -> itkTransformD33
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass_GetFixedTransform(self, *args)

    def SetMovingTransform(self, _arg):
        r"""
        SetMovingTransform(self, _arg)

        Parameters
        ----------
        _arg: itkTransformD33 *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass_SetMovingTransform(self, _arg)

    def GetModifiableMovingTransform(self):
        r"""GetModifiableMovingTransform(self) -> itkTransformD33"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass_GetModifiableMovingTransform(self)

    def GetMovingTransform(self, *args):
        r"""
        GetMovingTransform(self) -> itkTransformD33
        GetMovingTransform(self) -> itkTransformD33
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass_GetMovingTransform(self, *args)

    def SetTransform(self, transform):
        r"""
        SetTransform(self, transform)

        Parameters
        ----------
        transform: itkTransformD33 *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass_SetTransform(self, transform)

    def GetTransform(self):
        r"""GetTransform(self) -> itkTransformD33"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass_GetTransform(self)

    def GetNumberOfValidPoints(self):
        r"""GetNumberOfValidPoints(self) -> unsigned long"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass_GetNumberOfValidPoints(self)

    def SetVirtualDomain(self, spacing, origin, direction, region):
        r"""
        SetVirtualDomain(self, spacing, origin, direction, region)

        Parameters
        ----------
        spacing: itkVectorD3 const &
        origin: itkPointD3 const &
        direction: itkMatrixD33 const &
        region: itkImageRegion3 const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass_SetVirtualDomain(self, spacing, origin, direction, region)

    def SetVirtualDomainFromImage(self, virtualImage):
        r"""
        SetVirtualDomainFromImage(self, virtualImage)

        Parameters
        ----------
        virtualImage: itkImageD3 const *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass_SetVirtualDomainFromImage(self, virtualImage)

    def SupportsArbitraryVirtualDomainSamples(self):
        r"""SupportsArbitraryVirtualDomainSamples(self) -> bool"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass_SupportsArbitraryVirtualDomainSamples(self)

    def GetVirtualDomainTimeStamp(self):
        r"""GetVirtualDomainTimeStamp(self) -> itkTimeStamp"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass_GetVirtualDomainTimeStamp(self)

    def GetVirtualSpacing(self):
        r"""GetVirtualSpacing(self) -> itkVectorD3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass_GetVirtualSpacing(self)

    def GetVirtualOrigin(self):
        r"""GetVirtualOrigin(self) -> itkPointD3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass_GetVirtualOrigin(self)

    def GetVirtualDirection(self):
        r"""GetVirtualDirection(self) -> itkMatrixD33"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass_GetVirtualDirection(self)

    def GetVirtualRegion(self):
        r"""GetVirtualRegion(self) -> itkImageRegion3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass_GetVirtualRegion(self)

    def GetModifiableVirtualImage(self):
        r"""GetModifiableVirtualImage(self) -> itkImageD3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass_GetModifiableVirtualImage(self)

    def GetVirtualImage(self, *args):
        r"""
        GetVirtualImage(self) -> itkImageD3
        GetVirtualImage(self) -> itkImageD3
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass_GetVirtualImage(self, *args)

    def ComputeParameterOffsetFromVirtualIndex(self, index, numberOfLocalParameters):
        r"""
        ComputeParameterOffsetFromVirtualIndex(self, index, numberOfLocalParameters) -> long

        Parameters
        ----------
        index: itkIndex3 const &
        numberOfLocalParameters: unsigned int const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass_ComputeParameterOffsetFromVirtualIndex(self, index, numberOfLocalParameters)

    def ComputeParameterOffsetFromVirtualPoint(self, point, numberOfLocalParameters):
        r"""
        ComputeParameterOffsetFromVirtualPoint(self, point, numberOfLocalParameters) -> long

        Parameters
        ----------
        point: itkPointD3 const &
        numberOfLocalParameters: unsigned int const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass_ComputeParameterOffsetFromVirtualPoint(self, point, numberOfLocalParameters)

    def IsInsideVirtualDomain(self, *args):
        r"""
        IsInsideVirtualDomain(self, point) -> bool

        Parameters
        ----------
        point: itkPointD3 const &

        IsInsideVirtualDomain(self, index) -> bool

        Parameters
        ----------
        index: itkIndex3 const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass_IsInsideVirtualDomain(self, *args)
    __swig_destroy__ = _itkPointSetToPointSetMetricv4Python.delete_itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass_cast(obj)

# Register itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass in _itkPointSetToPointSetMetricv4Python:
_itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass_swigregister(itkPointSetToPointSetMetricv4PSUC3_Superclass_Superclass)
class itkPointSetToPointSetMetricv4PSD2_Superclass(itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass):
    r"""Proxy of C++ itkPointSetToPointSetMetricv4PSD2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetFixedPointSet(self, _arg):
        r"""
        SetFixedPointSet(self, _arg)

        Parameters
        ----------
        _arg: itkPointSetD2 const *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_SetFixedPointSet(self, _arg)

    def GetFixedPointSet(self):
        r"""GetFixedPointSet(self) -> itkPointSetD2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_GetFixedPointSet(self)

    def GetModifiableFixedTransformedPointSet(self):
        r"""GetModifiableFixedTransformedPointSet(self) -> itkPointSetD2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_GetModifiableFixedTransformedPointSet(self)

    def GetFixedTransformedPointSet(self, *args):
        r"""
        GetFixedTransformedPointSet(self) -> itkPointSetD2
        GetFixedTransformedPointSet(self) -> itkPointSetD2
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_GetFixedTransformedPointSet(self, *args)

    def SetMovingPointSet(self, _arg):
        r"""
        SetMovingPointSet(self, _arg)

        Parameters
        ----------
        _arg: itkPointSetD2 const *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_SetMovingPointSet(self, _arg)

    def GetMovingPointSet(self):
        r"""GetMovingPointSet(self) -> itkPointSetD2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_GetMovingPointSet(self)

    def GetModifiableMovingTransformedPointSet(self):
        r"""GetModifiableMovingTransformedPointSet(self) -> itkPointSetD2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_GetModifiableMovingTransformedPointSet(self)

    def GetMovingTransformedPointSet(self, *args):
        r"""
        GetMovingTransformedPointSet(self) -> itkPointSetD2
        GetMovingTransformedPointSet(self) -> itkPointSetD2
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_GetMovingTransformedPointSet(self, *args)

    def GetNumberOfComponents(self):
        r"""GetNumberOfComponents(self) -> unsigned long"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_GetNumberOfComponents(self)

    def GetVirtualTransformedPointSet(self):
        r"""GetVirtualTransformedPointSet(self) -> itkPointSetD2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_GetVirtualTransformedPointSet(self)

    def SetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self, _arg):
        r"""
        SetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_SetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self, _arg)

    def GetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self):
        r"""GetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self) -> bool"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_GetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self)

    def StoreDerivativeAsSparseFieldForLocalSupportTransformsOn(self):
        r"""StoreDerivativeAsSparseFieldForLocalSupportTransformsOn(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_StoreDerivativeAsSparseFieldForLocalSupportTransformsOn(self)

    def StoreDerivativeAsSparseFieldForLocalSupportTransformsOff(self):
        r"""StoreDerivativeAsSparseFieldForLocalSupportTransformsOff(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_StoreDerivativeAsSparseFieldForLocalSupportTransformsOff(self)

    def SetCalculateValueAndDerivativeInTangentSpace(self, _arg):
        r"""
        SetCalculateValueAndDerivativeInTangentSpace(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_SetCalculateValueAndDerivativeInTangentSpace(self, _arg)

    def GetCalculateValueAndDerivativeInTangentSpace(self):
        r"""GetCalculateValueAndDerivativeInTangentSpace(self) -> bool"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_GetCalculateValueAndDerivativeInTangentSpace(self)

    def CalculateValueAndDerivativeInTangentSpaceOn(self):
        r"""CalculateValueAndDerivativeInTangentSpaceOn(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_CalculateValueAndDerivativeInTangentSpaceOn(self)

    def CalculateValueAndDerivativeInTangentSpaceOff(self):
        r"""CalculateValueAndDerivativeInTangentSpaceOff(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_CalculateValueAndDerivativeInTangentSpaceOff(self)
    __swig_destroy__ = _itkPointSetToPointSetMetricv4Python.delete_itkPointSetToPointSetMetricv4PSD2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointSetToPointSetMetricv4PSD2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_cast(obj)

# Register itkPointSetToPointSetMetricv4PSD2_Superclass in _itkPointSetToPointSetMetricv4Python:
_itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_Superclass_swigregister(itkPointSetToPointSetMetricv4PSD2_Superclass)
class itkPointSetToPointSetMetricv4PSD3_Superclass(itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass):
    r"""Proxy of C++ itkPointSetToPointSetMetricv4PSD3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetFixedPointSet(self, _arg):
        r"""
        SetFixedPointSet(self, _arg)

        Parameters
        ----------
        _arg: itkPointSetD3 const *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_SetFixedPointSet(self, _arg)

    def GetFixedPointSet(self):
        r"""GetFixedPointSet(self) -> itkPointSetD3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_GetFixedPointSet(self)

    def GetModifiableFixedTransformedPointSet(self):
        r"""GetModifiableFixedTransformedPointSet(self) -> itkPointSetD3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_GetModifiableFixedTransformedPointSet(self)

    def GetFixedTransformedPointSet(self, *args):
        r"""
        GetFixedTransformedPointSet(self) -> itkPointSetD3
        GetFixedTransformedPointSet(self) -> itkPointSetD3
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_GetFixedTransformedPointSet(self, *args)

    def SetMovingPointSet(self, _arg):
        r"""
        SetMovingPointSet(self, _arg)

        Parameters
        ----------
        _arg: itkPointSetD3 const *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_SetMovingPointSet(self, _arg)

    def GetMovingPointSet(self):
        r"""GetMovingPointSet(self) -> itkPointSetD3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_GetMovingPointSet(self)

    def GetModifiableMovingTransformedPointSet(self):
        r"""GetModifiableMovingTransformedPointSet(self) -> itkPointSetD3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_GetModifiableMovingTransformedPointSet(self)

    def GetMovingTransformedPointSet(self, *args):
        r"""
        GetMovingTransformedPointSet(self) -> itkPointSetD3
        GetMovingTransformedPointSet(self) -> itkPointSetD3
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_GetMovingTransformedPointSet(self, *args)

    def GetNumberOfComponents(self):
        r"""GetNumberOfComponents(self) -> unsigned long"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_GetNumberOfComponents(self)

    def GetVirtualTransformedPointSet(self):
        r"""GetVirtualTransformedPointSet(self) -> itkPointSetD3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_GetVirtualTransformedPointSet(self)

    def SetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self, _arg):
        r"""
        SetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_SetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self, _arg)

    def GetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self):
        r"""GetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self) -> bool"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_GetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self)

    def StoreDerivativeAsSparseFieldForLocalSupportTransformsOn(self):
        r"""StoreDerivativeAsSparseFieldForLocalSupportTransformsOn(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_StoreDerivativeAsSparseFieldForLocalSupportTransformsOn(self)

    def StoreDerivativeAsSparseFieldForLocalSupportTransformsOff(self):
        r"""StoreDerivativeAsSparseFieldForLocalSupportTransformsOff(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_StoreDerivativeAsSparseFieldForLocalSupportTransformsOff(self)

    def SetCalculateValueAndDerivativeInTangentSpace(self, _arg):
        r"""
        SetCalculateValueAndDerivativeInTangentSpace(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_SetCalculateValueAndDerivativeInTangentSpace(self, _arg)

    def GetCalculateValueAndDerivativeInTangentSpace(self):
        r"""GetCalculateValueAndDerivativeInTangentSpace(self) -> bool"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_GetCalculateValueAndDerivativeInTangentSpace(self)

    def CalculateValueAndDerivativeInTangentSpaceOn(self):
        r"""CalculateValueAndDerivativeInTangentSpaceOn(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_CalculateValueAndDerivativeInTangentSpaceOn(self)

    def CalculateValueAndDerivativeInTangentSpaceOff(self):
        r"""CalculateValueAndDerivativeInTangentSpaceOff(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_CalculateValueAndDerivativeInTangentSpaceOff(self)
    __swig_destroy__ = _itkPointSetToPointSetMetricv4Python.delete_itkPointSetToPointSetMetricv4PSD3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointSetToPointSetMetricv4PSD3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_cast(obj)

# Register itkPointSetToPointSetMetricv4PSD3_Superclass in _itkPointSetToPointSetMetricv4Python:
_itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_Superclass_swigregister(itkPointSetToPointSetMetricv4PSD3_Superclass)
class itkPointSetToPointSetMetricv4PSF2_Superclass(itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass):
    r"""Proxy of C++ itkPointSetToPointSetMetricv4PSF2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetFixedPointSet(self, _arg):
        r"""
        SetFixedPointSet(self, _arg)

        Parameters
        ----------
        _arg: itkPointSetF2 const *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_SetFixedPointSet(self, _arg)

    def GetFixedPointSet(self):
        r"""GetFixedPointSet(self) -> itkPointSetF2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_GetFixedPointSet(self)

    def GetModifiableFixedTransformedPointSet(self):
        r"""GetModifiableFixedTransformedPointSet(self) -> itkPointSetF2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_GetModifiableFixedTransformedPointSet(self)

    def GetFixedTransformedPointSet(self, *args):
        r"""
        GetFixedTransformedPointSet(self) -> itkPointSetF2
        GetFixedTransformedPointSet(self) -> itkPointSetF2
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_GetFixedTransformedPointSet(self, *args)

    def SetMovingPointSet(self, _arg):
        r"""
        SetMovingPointSet(self, _arg)

        Parameters
        ----------
        _arg: itkPointSetF2 const *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_SetMovingPointSet(self, _arg)

    def GetMovingPointSet(self):
        r"""GetMovingPointSet(self) -> itkPointSetF2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_GetMovingPointSet(self)

    def GetModifiableMovingTransformedPointSet(self):
        r"""GetModifiableMovingTransformedPointSet(self) -> itkPointSetF2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_GetModifiableMovingTransformedPointSet(self)

    def GetMovingTransformedPointSet(self, *args):
        r"""
        GetMovingTransformedPointSet(self) -> itkPointSetF2
        GetMovingTransformedPointSet(self) -> itkPointSetF2
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_GetMovingTransformedPointSet(self, *args)

    def GetNumberOfComponents(self):
        r"""GetNumberOfComponents(self) -> unsigned long"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_GetNumberOfComponents(self)

    def GetVirtualTransformedPointSet(self):
        r"""GetVirtualTransformedPointSet(self) -> itkPointSetD2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_GetVirtualTransformedPointSet(self)

    def SetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self, _arg):
        r"""
        SetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_SetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self, _arg)

    def GetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self):
        r"""GetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self) -> bool"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_GetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self)

    def StoreDerivativeAsSparseFieldForLocalSupportTransformsOn(self):
        r"""StoreDerivativeAsSparseFieldForLocalSupportTransformsOn(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_StoreDerivativeAsSparseFieldForLocalSupportTransformsOn(self)

    def StoreDerivativeAsSparseFieldForLocalSupportTransformsOff(self):
        r"""StoreDerivativeAsSparseFieldForLocalSupportTransformsOff(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_StoreDerivativeAsSparseFieldForLocalSupportTransformsOff(self)

    def SetCalculateValueAndDerivativeInTangentSpace(self, _arg):
        r"""
        SetCalculateValueAndDerivativeInTangentSpace(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_SetCalculateValueAndDerivativeInTangentSpace(self, _arg)

    def GetCalculateValueAndDerivativeInTangentSpace(self):
        r"""GetCalculateValueAndDerivativeInTangentSpace(self) -> bool"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_GetCalculateValueAndDerivativeInTangentSpace(self)

    def CalculateValueAndDerivativeInTangentSpaceOn(self):
        r"""CalculateValueAndDerivativeInTangentSpaceOn(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_CalculateValueAndDerivativeInTangentSpaceOn(self)

    def CalculateValueAndDerivativeInTangentSpaceOff(self):
        r"""CalculateValueAndDerivativeInTangentSpaceOff(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_CalculateValueAndDerivativeInTangentSpaceOff(self)
    __swig_destroy__ = _itkPointSetToPointSetMetricv4Python.delete_itkPointSetToPointSetMetricv4PSF2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointSetToPointSetMetricv4PSF2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_cast(obj)

# Register itkPointSetToPointSetMetricv4PSF2_Superclass in _itkPointSetToPointSetMetricv4Python:
_itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_Superclass_swigregister(itkPointSetToPointSetMetricv4PSF2_Superclass)
class itkPointSetToPointSetMetricv4PSF3_Superclass(itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass):
    r"""Proxy of C++ itkPointSetToPointSetMetricv4PSF3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetFixedPointSet(self, _arg):
        r"""
        SetFixedPointSet(self, _arg)

        Parameters
        ----------
        _arg: itkPointSetF3 const *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_SetFixedPointSet(self, _arg)

    def GetFixedPointSet(self):
        r"""GetFixedPointSet(self) -> itkPointSetF3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_GetFixedPointSet(self)

    def GetModifiableFixedTransformedPointSet(self):
        r"""GetModifiableFixedTransformedPointSet(self) -> itkPointSetF3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_GetModifiableFixedTransformedPointSet(self)

    def GetFixedTransformedPointSet(self, *args):
        r"""
        GetFixedTransformedPointSet(self) -> itkPointSetF3
        GetFixedTransformedPointSet(self) -> itkPointSetF3
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_GetFixedTransformedPointSet(self, *args)

    def SetMovingPointSet(self, _arg):
        r"""
        SetMovingPointSet(self, _arg)

        Parameters
        ----------
        _arg: itkPointSetF3 const *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_SetMovingPointSet(self, _arg)

    def GetMovingPointSet(self):
        r"""GetMovingPointSet(self) -> itkPointSetF3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_GetMovingPointSet(self)

    def GetModifiableMovingTransformedPointSet(self):
        r"""GetModifiableMovingTransformedPointSet(self) -> itkPointSetF3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_GetModifiableMovingTransformedPointSet(self)

    def GetMovingTransformedPointSet(self, *args):
        r"""
        GetMovingTransformedPointSet(self) -> itkPointSetF3
        GetMovingTransformedPointSet(self) -> itkPointSetF3
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_GetMovingTransformedPointSet(self, *args)

    def GetNumberOfComponents(self):
        r"""GetNumberOfComponents(self) -> unsigned long"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_GetNumberOfComponents(self)

    def GetVirtualTransformedPointSet(self):
        r"""GetVirtualTransformedPointSet(self) -> itkPointSetD3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_GetVirtualTransformedPointSet(self)

    def SetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self, _arg):
        r"""
        SetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_SetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self, _arg)

    def GetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self):
        r"""GetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self) -> bool"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_GetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self)

    def StoreDerivativeAsSparseFieldForLocalSupportTransformsOn(self):
        r"""StoreDerivativeAsSparseFieldForLocalSupportTransformsOn(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_StoreDerivativeAsSparseFieldForLocalSupportTransformsOn(self)

    def StoreDerivativeAsSparseFieldForLocalSupportTransformsOff(self):
        r"""StoreDerivativeAsSparseFieldForLocalSupportTransformsOff(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_StoreDerivativeAsSparseFieldForLocalSupportTransformsOff(self)

    def SetCalculateValueAndDerivativeInTangentSpace(self, _arg):
        r"""
        SetCalculateValueAndDerivativeInTangentSpace(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_SetCalculateValueAndDerivativeInTangentSpace(self, _arg)

    def GetCalculateValueAndDerivativeInTangentSpace(self):
        r"""GetCalculateValueAndDerivativeInTangentSpace(self) -> bool"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_GetCalculateValueAndDerivativeInTangentSpace(self)

    def CalculateValueAndDerivativeInTangentSpaceOn(self):
        r"""CalculateValueAndDerivativeInTangentSpaceOn(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_CalculateValueAndDerivativeInTangentSpaceOn(self)

    def CalculateValueAndDerivativeInTangentSpaceOff(self):
        r"""CalculateValueAndDerivativeInTangentSpaceOff(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_CalculateValueAndDerivativeInTangentSpaceOff(self)
    __swig_destroy__ = _itkPointSetToPointSetMetricv4Python.delete_itkPointSetToPointSetMetricv4PSF3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointSetToPointSetMetricv4PSF3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_cast(obj)

# Register itkPointSetToPointSetMetricv4PSF3_Superclass in _itkPointSetToPointSetMetricv4Python:
_itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_Superclass_swigregister(itkPointSetToPointSetMetricv4PSF3_Superclass)
class itkPointSetToPointSetMetricv4PSSS2_Superclass(itkPointSetToPointSetMetricv4PSSS2_Superclass_Superclass):
    r"""Proxy of C++ itkPointSetToPointSetMetricv4PSSS2_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetFixedPointSet(self, _arg):
        r"""
        SetFixedPointSet(self, _arg)

        Parameters
        ----------
        _arg: itkPointSetSS2 const *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_SetFixedPointSet(self, _arg)

    def GetFixedPointSet(self):
        r"""GetFixedPointSet(self) -> itkPointSetSS2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_GetFixedPointSet(self)

    def GetModifiableFixedTransformedPointSet(self):
        r"""GetModifiableFixedTransformedPointSet(self) -> itkPointSetSS2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_GetModifiableFixedTransformedPointSet(self)

    def GetFixedTransformedPointSet(self, *args):
        r"""
        GetFixedTransformedPointSet(self) -> itkPointSetSS2
        GetFixedTransformedPointSet(self) -> itkPointSetSS2
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_GetFixedTransformedPointSet(self, *args)

    def SetMovingPointSet(self, _arg):
        r"""
        SetMovingPointSet(self, _arg)

        Parameters
        ----------
        _arg: itkPointSetSS2 const *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_SetMovingPointSet(self, _arg)

    def GetMovingPointSet(self):
        r"""GetMovingPointSet(self) -> itkPointSetSS2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_GetMovingPointSet(self)

    def GetModifiableMovingTransformedPointSet(self):
        r"""GetModifiableMovingTransformedPointSet(self) -> itkPointSetSS2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_GetModifiableMovingTransformedPointSet(self)

    def GetMovingTransformedPointSet(self, *args):
        r"""
        GetMovingTransformedPointSet(self) -> itkPointSetSS2
        GetMovingTransformedPointSet(self) -> itkPointSetSS2
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_GetMovingTransformedPointSet(self, *args)

    def GetNumberOfComponents(self):
        r"""GetNumberOfComponents(self) -> unsigned long"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_GetNumberOfComponents(self)

    def GetVirtualTransformedPointSet(self):
        r"""GetVirtualTransformedPointSet(self) -> itkPointSetD2"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_GetVirtualTransformedPointSet(self)

    def SetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self, _arg):
        r"""
        SetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_SetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self, _arg)

    def GetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self):
        r"""GetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self) -> bool"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_GetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self)

    def StoreDerivativeAsSparseFieldForLocalSupportTransformsOn(self):
        r"""StoreDerivativeAsSparseFieldForLocalSupportTransformsOn(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_StoreDerivativeAsSparseFieldForLocalSupportTransformsOn(self)

    def StoreDerivativeAsSparseFieldForLocalSupportTransformsOff(self):
        r"""StoreDerivativeAsSparseFieldForLocalSupportTransformsOff(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_StoreDerivativeAsSparseFieldForLocalSupportTransformsOff(self)

    def SetCalculateValueAndDerivativeInTangentSpace(self, _arg):
        r"""
        SetCalculateValueAndDerivativeInTangentSpace(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_SetCalculateValueAndDerivativeInTangentSpace(self, _arg)

    def GetCalculateValueAndDerivativeInTangentSpace(self):
        r"""GetCalculateValueAndDerivativeInTangentSpace(self) -> bool"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_GetCalculateValueAndDerivativeInTangentSpace(self)

    def CalculateValueAndDerivativeInTangentSpaceOn(self):
        r"""CalculateValueAndDerivativeInTangentSpaceOn(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_CalculateValueAndDerivativeInTangentSpaceOn(self)

    def CalculateValueAndDerivativeInTangentSpaceOff(self):
        r"""CalculateValueAndDerivativeInTangentSpaceOff(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_CalculateValueAndDerivativeInTangentSpaceOff(self)
    __swig_destroy__ = _itkPointSetToPointSetMetricv4Python.delete_itkPointSetToPointSetMetricv4PSSS2_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointSetToPointSetMetricv4PSSS2_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_cast(obj)

# Register itkPointSetToPointSetMetricv4PSSS2_Superclass in _itkPointSetToPointSetMetricv4Python:
_itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_Superclass_swigregister(itkPointSetToPointSetMetricv4PSSS2_Superclass)
class itkPointSetToPointSetMetricv4PSSS3_Superclass(itkPointSetToPointSetMetricv4PSSS3_Superclass_Superclass):
    r"""Proxy of C++ itkPointSetToPointSetMetricv4PSSS3_Superclass class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def SetFixedPointSet(self, _arg):
        r"""
        SetFixedPointSet(self, _arg)

        Parameters
        ----------
        _arg: itkPointSetSS3 const *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_SetFixedPointSet(self, _arg)

    def GetFixedPointSet(self):
        r"""GetFixedPointSet(self) -> itkPointSetSS3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_GetFixedPointSet(self)

    def GetModifiableFixedTransformedPointSet(self):
        r"""GetModifiableFixedTransformedPointSet(self) -> itkPointSetSS3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_GetModifiableFixedTransformedPointSet(self)

    def GetFixedTransformedPointSet(self, *args):
        r"""
        GetFixedTransformedPointSet(self) -> itkPointSetSS3
        GetFixedTransformedPointSet(self) -> itkPointSetSS3
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_GetFixedTransformedPointSet(self, *args)

    def SetMovingPointSet(self, _arg):
        r"""
        SetMovingPointSet(self, _arg)

        Parameters
        ----------
        _arg: itkPointSetSS3 const *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_SetMovingPointSet(self, _arg)

    def GetMovingPointSet(self):
        r"""GetMovingPointSet(self) -> itkPointSetSS3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_GetMovingPointSet(self)

    def GetModifiableMovingTransformedPointSet(self):
        r"""GetModifiableMovingTransformedPointSet(self) -> itkPointSetSS3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_GetModifiableMovingTransformedPointSet(self)

    def GetMovingTransformedPointSet(self, *args):
        r"""
        GetMovingTransformedPointSet(self) -> itkPointSetSS3
        GetMovingTransformedPointSet(self) -> itkPointSetSS3
        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_GetMovingTransformedPointSet(self, *args)

    def GetNumberOfComponents(self):
        r"""GetNumberOfComponents(self) -> unsigned long"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_GetNumberOfComponents(self)

    def GetVirtualTransformedPointSet(self):
        r"""GetVirtualTransformedPointSet(self) -> itkPointSetD3"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_GetVirtualTransformedPointSet(self)

    def SetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self, _arg):
        r"""
        SetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_SetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self, _arg)

    def GetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self):
        r"""GetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self) -> bool"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_GetStoreDerivativeAsSparseFieldForLocalSupportTransforms(self)

    def StoreDerivativeAsSparseFieldForLocalSupportTransformsOn(self):
        r"""StoreDerivativeAsSparseFieldForLocalSupportTransformsOn(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_StoreDerivativeAsSparseFieldForLocalSupportTransformsOn(self)

    def StoreDerivativeAsSparseFieldForLocalSupportTransformsOff(self):
        r"""StoreDerivativeAsSparseFieldForLocalSupportTransformsOff(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_StoreDerivativeAsSparseFieldForLocalSupportTransformsOff(self)

    def SetCalculateValueAndDerivativeInTangentSpace(self, _arg):
        r"""
        SetCalculateValueAndDerivativeInTangentSpace(self, _arg)

        Parameters
        ----------
        _arg: bool

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_SetCalculateValueAndDerivativeInTangentSpace(self, _arg)

    def GetCalculateValueAndDerivativeInTangentSpace(self):
        r"""GetCalculateValueAndDerivativeInTangentSpace(self) -> bool"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_GetCalculateValueAndDerivativeInTangentSpace(self)

    def CalculateValueAndDerivativeInTangentSpaceOn(self):
        r"""CalculateValueAndDerivativeInTangentSpaceOn(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_CalculateValueAndDerivativeInTangentSpaceOn(self)

    def CalculateValueAndDerivativeInTangentSpaceOff(self):
        r"""CalculateValueAndDerivativeInTangentSpaceOff(self)"""
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_CalculateValueAndDerivativeInTangentSpaceOff(self)
    __swig_destroy__ = _itkPointSetToPointSetMetricv4Python.delete_itkPointSetToPointSetMetricv4PSSS3_Superclass

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointSetToPointSetMetricv4PSSS3_Superclass

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_cast(obj)

# Register itkPointSetToPointSetMetricv4PSSS3_Superclass in _itkPointSetToPointSetMetricv4Python:
_itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_Superclass_swigregister(itkPointSetToPointSetMetricv4PSSS3_Superclass)
class itkPointSetToPointSetMetricv4PSUC2(itkPointSetToPointSetMetricv4PSUC2_Superclass):
    r"""Proxy of C++ itkPointSetToPointSetMetricv4PSUC2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def GetLocalNeighborhoodValue(self, arg0, pixel):
        r"""
        GetLocalNeighborhoodValue(self, arg0, pixel) -> double

        Parameters
        ----------
        arg0: itkPointF2 const &
        pixel: unsigned char const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_GetLocalNeighborhoodValue(self, arg0, pixel)

    def GetLocalNeighborhoodDerivative(self, arg0, pixel):
        r"""
        GetLocalNeighborhoodDerivative(self, arg0, pixel) -> itkFixedArrayD2

        Parameters
        ----------
        arg0: itkPointF2 const &
        pixel: unsigned char const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_GetLocalNeighborhoodDerivative(self, arg0, pixel)

    def GetLocalNeighborhoodValueAndDerivative(self, arg0, arg1, arg2, pixel):
        r"""
        GetLocalNeighborhoodValueAndDerivative(self, arg0, arg1, arg2, pixel)

        Parameters
        ----------
        arg0: itkPointF2 const &
        arg1: double &
        arg2: itkFixedArrayD2 &
        pixel: unsigned char const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_GetLocalNeighborhoodValueAndDerivative(self, arg0, arg1, arg2, pixel)
    __swig_destroy__ = _itkPointSetToPointSetMetricv4Python.delete_itkPointSetToPointSetMetricv4PSUC2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointSetToPointSetMetricv4PSUC2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_cast(obj)

# Register itkPointSetToPointSetMetricv4PSUC2 in _itkPointSetToPointSetMetricv4Python:
_itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC2_swigregister(itkPointSetToPointSetMetricv4PSUC2)
class itkPointSetToPointSetMetricv4PSUC3(itkPointSetToPointSetMetricv4PSUC3_Superclass):
    r"""Proxy of C++ itkPointSetToPointSetMetricv4PSUC3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def GetLocalNeighborhoodValue(self, arg0, pixel):
        r"""
        GetLocalNeighborhoodValue(self, arg0, pixel) -> double

        Parameters
        ----------
        arg0: itkPointF3 const &
        pixel: unsigned char const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_GetLocalNeighborhoodValue(self, arg0, pixel)

    def GetLocalNeighborhoodDerivative(self, arg0, pixel):
        r"""
        GetLocalNeighborhoodDerivative(self, arg0, pixel) -> itkFixedArrayD3

        Parameters
        ----------
        arg0: itkPointF3 const &
        pixel: unsigned char const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_GetLocalNeighborhoodDerivative(self, arg0, pixel)

    def GetLocalNeighborhoodValueAndDerivative(self, arg0, arg1, arg2, pixel):
        r"""
        GetLocalNeighborhoodValueAndDerivative(self, arg0, arg1, arg2, pixel)

        Parameters
        ----------
        arg0: itkPointF3 const &
        arg1: double &
        arg2: itkFixedArrayD3 &
        pixel: unsigned char const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_GetLocalNeighborhoodValueAndDerivative(self, arg0, arg1, arg2, pixel)
    __swig_destroy__ = _itkPointSetToPointSetMetricv4Python.delete_itkPointSetToPointSetMetricv4PSUC3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointSetToPointSetMetricv4PSUC3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_cast(obj)

# Register itkPointSetToPointSetMetricv4PSUC3 in _itkPointSetToPointSetMetricv4Python:
_itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSUC3_swigregister(itkPointSetToPointSetMetricv4PSUC3)
class itkPointSetToPointSetMetricv4PSD2(itkPointSetToPointSetMetricv4PSD2_Superclass):
    r"""Proxy of C++ itkPointSetToPointSetMetricv4PSD2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def GetLocalNeighborhoodValue(self, arg0, pixel):
        r"""
        GetLocalNeighborhoodValue(self, arg0, pixel) -> double

        Parameters
        ----------
        arg0: itkPointF2 const &
        pixel: double const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_GetLocalNeighborhoodValue(self, arg0, pixel)

    def GetLocalNeighborhoodDerivative(self, arg0, pixel):
        r"""
        GetLocalNeighborhoodDerivative(self, arg0, pixel) -> itkFixedArrayD2

        Parameters
        ----------
        arg0: itkPointF2 const &
        pixel: double const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_GetLocalNeighborhoodDerivative(self, arg0, pixel)

    def GetLocalNeighborhoodValueAndDerivative(self, arg0, arg1, arg2, pixel):
        r"""
        GetLocalNeighborhoodValueAndDerivative(self, arg0, arg1, arg2, pixel)

        Parameters
        ----------
        arg0: itkPointF2 const &
        arg1: double &
        arg2: itkFixedArrayD2 &
        pixel: double const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_GetLocalNeighborhoodValueAndDerivative(self, arg0, arg1, arg2, pixel)
    __swig_destroy__ = _itkPointSetToPointSetMetricv4Python.delete_itkPointSetToPointSetMetricv4PSD2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointSetToPointSetMetricv4PSD2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_cast(obj)

# Register itkPointSetToPointSetMetricv4PSD2 in _itkPointSetToPointSetMetricv4Python:
_itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD2_swigregister(itkPointSetToPointSetMetricv4PSD2)
class itkPointSetToPointSetMetricv4PSD3(itkPointSetToPointSetMetricv4PSD3_Superclass):
    r"""Proxy of C++ itkPointSetToPointSetMetricv4PSD3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def GetLocalNeighborhoodValue(self, arg0, pixel):
        r"""
        GetLocalNeighborhoodValue(self, arg0, pixel) -> double

        Parameters
        ----------
        arg0: itkPointF3 const &
        pixel: double const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_GetLocalNeighborhoodValue(self, arg0, pixel)

    def GetLocalNeighborhoodDerivative(self, arg0, pixel):
        r"""
        GetLocalNeighborhoodDerivative(self, arg0, pixel) -> itkFixedArrayD3

        Parameters
        ----------
        arg0: itkPointF3 const &
        pixel: double const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_GetLocalNeighborhoodDerivative(self, arg0, pixel)

    def GetLocalNeighborhoodValueAndDerivative(self, arg0, arg1, arg2, pixel):
        r"""
        GetLocalNeighborhoodValueAndDerivative(self, arg0, arg1, arg2, pixel)

        Parameters
        ----------
        arg0: itkPointF3 const &
        arg1: double &
        arg2: itkFixedArrayD3 &
        pixel: double const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_GetLocalNeighborhoodValueAndDerivative(self, arg0, arg1, arg2, pixel)
    __swig_destroy__ = _itkPointSetToPointSetMetricv4Python.delete_itkPointSetToPointSetMetricv4PSD3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointSetToPointSetMetricv4PSD3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_cast(obj)

# Register itkPointSetToPointSetMetricv4PSD3 in _itkPointSetToPointSetMetricv4Python:
_itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSD3_swigregister(itkPointSetToPointSetMetricv4PSD3)
class itkPointSetToPointSetMetricv4PSF2(itkPointSetToPointSetMetricv4PSF2_Superclass):
    r"""Proxy of C++ itkPointSetToPointSetMetricv4PSF2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def GetLocalNeighborhoodValue(self, arg0, pixel):
        r"""
        GetLocalNeighborhoodValue(self, arg0, pixel) -> double

        Parameters
        ----------
        arg0: itkPointF2 const &
        pixel: float const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_GetLocalNeighborhoodValue(self, arg0, pixel)

    def GetLocalNeighborhoodDerivative(self, arg0, pixel):
        r"""
        GetLocalNeighborhoodDerivative(self, arg0, pixel) -> itkFixedArrayD2

        Parameters
        ----------
        arg0: itkPointF2 const &
        pixel: float const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_GetLocalNeighborhoodDerivative(self, arg0, pixel)

    def GetLocalNeighborhoodValueAndDerivative(self, arg0, arg1, arg2, pixel):
        r"""
        GetLocalNeighborhoodValueAndDerivative(self, arg0, arg1, arg2, pixel)

        Parameters
        ----------
        arg0: itkPointF2 const &
        arg1: double &
        arg2: itkFixedArrayD2 &
        pixel: float const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_GetLocalNeighborhoodValueAndDerivative(self, arg0, arg1, arg2, pixel)
    __swig_destroy__ = _itkPointSetToPointSetMetricv4Python.delete_itkPointSetToPointSetMetricv4PSF2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointSetToPointSetMetricv4PSF2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_cast(obj)

# Register itkPointSetToPointSetMetricv4PSF2 in _itkPointSetToPointSetMetricv4Python:
_itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF2_swigregister(itkPointSetToPointSetMetricv4PSF2)
class itkPointSetToPointSetMetricv4PSF3(itkPointSetToPointSetMetricv4PSF3_Superclass):
    r"""Proxy of C++ itkPointSetToPointSetMetricv4PSF3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def GetLocalNeighborhoodValue(self, arg0, pixel):
        r"""
        GetLocalNeighborhoodValue(self, arg0, pixel) -> double

        Parameters
        ----------
        arg0: itkPointF3 const &
        pixel: float const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_GetLocalNeighborhoodValue(self, arg0, pixel)

    def GetLocalNeighborhoodDerivative(self, arg0, pixel):
        r"""
        GetLocalNeighborhoodDerivative(self, arg0, pixel) -> itkFixedArrayD3

        Parameters
        ----------
        arg0: itkPointF3 const &
        pixel: float const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_GetLocalNeighborhoodDerivative(self, arg0, pixel)

    def GetLocalNeighborhoodValueAndDerivative(self, arg0, arg1, arg2, pixel):
        r"""
        GetLocalNeighborhoodValueAndDerivative(self, arg0, arg1, arg2, pixel)

        Parameters
        ----------
        arg0: itkPointF3 const &
        arg1: double &
        arg2: itkFixedArrayD3 &
        pixel: float const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_GetLocalNeighborhoodValueAndDerivative(self, arg0, arg1, arg2, pixel)
    __swig_destroy__ = _itkPointSetToPointSetMetricv4Python.delete_itkPointSetToPointSetMetricv4PSF3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointSetToPointSetMetricv4PSF3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_cast(obj)

# Register itkPointSetToPointSetMetricv4PSF3 in _itkPointSetToPointSetMetricv4Python:
_itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSF3_swigregister(itkPointSetToPointSetMetricv4PSF3)
class itkPointSetToPointSetMetricv4PSSS2(itkPointSetToPointSetMetricv4PSSS2_Superclass):
    r"""Proxy of C++ itkPointSetToPointSetMetricv4PSSS2 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def GetLocalNeighborhoodValue(self, arg0, pixel):
        r"""
        GetLocalNeighborhoodValue(self, arg0, pixel) -> double

        Parameters
        ----------
        arg0: itkPointF2 const &
        pixel: short const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_GetLocalNeighborhoodValue(self, arg0, pixel)

    def GetLocalNeighborhoodDerivative(self, arg0, pixel):
        r"""
        GetLocalNeighborhoodDerivative(self, arg0, pixel) -> itkFixedArrayD2

        Parameters
        ----------
        arg0: itkPointF2 const &
        pixel: short const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_GetLocalNeighborhoodDerivative(self, arg0, pixel)

    def GetLocalNeighborhoodValueAndDerivative(self, arg0, arg1, arg2, pixel):
        r"""
        GetLocalNeighborhoodValueAndDerivative(self, arg0, arg1, arg2, pixel)

        Parameters
        ----------
        arg0: itkPointF2 const &
        arg1: double &
        arg2: itkFixedArrayD2 &
        pixel: short const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_GetLocalNeighborhoodValueAndDerivative(self, arg0, arg1, arg2, pixel)
    __swig_destroy__ = _itkPointSetToPointSetMetricv4Python.delete_itkPointSetToPointSetMetricv4PSSS2

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointSetToPointSetMetricv4PSSS2

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_cast(obj)

# Register itkPointSetToPointSetMetricv4PSSS2 in _itkPointSetToPointSetMetricv4Python:
_itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS2_swigregister(itkPointSetToPointSetMetricv4PSSS2)
class itkPointSetToPointSetMetricv4PSSS3(itkPointSetToPointSetMetricv4PSSS3_Superclass):
    r"""Proxy of C++ itkPointSetToPointSetMetricv4PSSS3 class."""

    thisown = property(lambda x: x.this.own(), lambda x, v: x.this.own(v), doc="The membership flag")

    def __init__(self, *args, **kwargs):
        raise AttributeError("No constructor defined - class is abstract")
    __repr__ = _swig_repr

    def GetLocalNeighborhoodValue(self, arg0, pixel):
        r"""
        GetLocalNeighborhoodValue(self, arg0, pixel) -> double

        Parameters
        ----------
        arg0: itkPointF3 const &
        pixel: short const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_GetLocalNeighborhoodValue(self, arg0, pixel)

    def GetLocalNeighborhoodDerivative(self, arg0, pixel):
        r"""
        GetLocalNeighborhoodDerivative(self, arg0, pixel) -> itkFixedArrayD3

        Parameters
        ----------
        arg0: itkPointF3 const &
        pixel: short const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_GetLocalNeighborhoodDerivative(self, arg0, pixel)

    def GetLocalNeighborhoodValueAndDerivative(self, arg0, arg1, arg2, pixel):
        r"""
        GetLocalNeighborhoodValueAndDerivative(self, arg0, arg1, arg2, pixel)

        Parameters
        ----------
        arg0: itkPointF3 const &
        arg1: double &
        arg2: itkFixedArrayD3 &
        pixel: short const &

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_GetLocalNeighborhoodValueAndDerivative(self, arg0, arg1, arg2, pixel)
    __swig_destroy__ = _itkPointSetToPointSetMetricv4Python.delete_itkPointSetToPointSetMetricv4PSSS3

    @staticmethod
    def cast(obj):
        r"""
        cast(obj) -> itkPointSetToPointSetMetricv4PSSS3

        Parameters
        ----------
        obj: itkLightObject *

        """
        return _itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_cast(obj)

# Register itkPointSetToPointSetMetricv4PSSS3 in _itkPointSetToPointSetMetricv4Python:
_itkPointSetToPointSetMetricv4Python.itkPointSetToPointSetMetricv4PSSS3_swigregister(itkPointSetToPointSetMetricv4PSSS3)

